
(function ($, window, document, undefined) {

    "use strict";

    // create the defaults once
    var pluginName = "easytheme",
            defaults = {
                // themes
                ct_dark_elm: ".easytheme-dark-btn",
                ct_light_elm: ".easytheme-light-btn",
                ct_normal_elm: ".easytheme-normal-btn",
                // toolbar
                tb_wrapper_elm: "#easytheme-toolbarWrap",
                tb_btn_elm: ".easytheme_hide_toolbar",        
            };

    // plugin constructor
    function Plugin(element, options) {
        this.element = element; 
        this.settings = $.extend({}, defaults, options);
        this._defaults = defaults;
        this._name = pluginName;
        this.init();
        
    }

    // avoid Plugin.prototype conflicts
    $.extend(Plugin.prototype, {
        init: function () {
            
            // console.log("start init easytheme");

            this.initToolbar(this.settings);
            this.initContrast(this.settings);
                        
            // console.log("end init easytheme");
            
        },
                
        initToolbar: function (plg_settings){
            
            $(plg_settings.tb_btn_elm).click(function (event) {
                
                $(plg_settings.tb_wrapper_elm).toggleClass("close-toolbar");

                if ($(plg_settings.tb_wrapper_elm).hasClass('close-toolbar')) {
                    $(plg_settings.tb_wrapper_elm).children("a, button,h3").attr('tabindex', '-1');
                }
                else {
                    $(plg_settings.tb_wrapper_elm).children("a, button,h3").attr('tabindex', '0');
                }

            });
            
            $(plg_settings.tb_btn_elm).focus(function (event) {
                
                $(plg_settings.tb_wrapper_elm).toggleClass("close-toolbar");

                if ($(plg_settings.tb_wrapper_elm).hasClass('close-toolbar')) {
                    $(plg_settings.tb_wrapper_elm).children("a, button,h3").attr('tabindex', '-1');
                }
                else {
                    $(plg_settings.tb_wrapper_elm).children("a, button,h3").attr('tabindex', '0');
                }

            });
        },
        
        initContrast: function(plg_settings){
            
            var easytheme_dark =  localStorage.getItem('easytheme_dark');
            var easytheme_light = localStorage.getItem('easytheme_light');
            
            // dark theme
            $( plg_settings.ct_dark_elm ).click( function () {
                localStorage.removeItem('easytheme_light');
                localStorage.setItem('easytheme_dark','dark',1);

                $( 'body' )
                    .removeClass( 'easytheme-light' )
                    .addClass( 'easytheme-dark' );

                $( plg_settings.ct_normal_elm ).removeClass( 'easytheme-hide' );
            });
            
            // light theme
            $( plg_settings.ct_light_elm ).click( this ,function () {
                localStorage.removeItem( 'easytheme_dark' );
                localStorage.setItem('easytheme_light','light',1);

                $( 'body' )
                    .removeClass( 'easytheme-dark' )
                    .addClass( 'easytheme-light' );

                $( plg_settings.ct_normal_elm).removeClass( 'easytheme-hide' );
            });
            
            // normal theme
            $(plg_settings.ct_normal_elm ).click(this, function () {
            
                localStorage.removeItem( 'easytheme_dark' );
                localStorage.removeItem( 'easytheme_light' );

                $(plg_settings.ct_normal_elm).addClass( 'easytheme-hide' );

                $( 'body' ).removeClass( 'easytheme-dark easytheme-light' );
            });
            
            // initialize from localStorage
            if ( easytheme_dark ) {
                $( 'body' )
                    .removeClass( 'easytheme-light' )
                    .addClass( 'easytheme-dark' );

                $( plg_settings.ct_normal_elm ).removeClass( 'easytheme-hide' );
            }

            if( easytheme_light ) {
                $( 'body' )
                    .removeClass( 'easytheme-dark' )
                    .addClass( 'easytheme-light' );

                $( plg_settings.ct_normal_elm ).removeClass( 'easytheme-hide' );
            }
            
        },
                     
    });

    // lightweight plugin wrapper around the constructor, preventing against multiple instantiations
    $.fn[ pluginName ] = function (options) {
        return this.each(function () {
            if (!$.data(this, "plugin_" + pluginName)) {
                $.data(this, "plugin_" + pluginName, new Plugin(this, options));
            }
        });
    };

})(jQuery, window, document);

function deselect(e) {
    jQuery('.pop').slideFadeToggle(function() {
        e.removeClass('selected');
    });
}

jQuery.fn.slideFadeToggle = function(easing, callback) {
    return this.animate({ opacity: 'toggle', height: 'toggle' }, 'fast', easing, callback);
};

// activate plugin after dom ready
jQuery(document).ready(function ($) {
    var ajaxUrl = 'index.php?option=com_ajax&module=easytheme&format=json&method=get';
    var data = {
        action: 'easytheme_toolbar_ajax',
    };
    $.post(ajaxUrl, data, function(response) {
        $('.easytheme-show-statement').on('click', function() {
            if($(this).hasClass('selected')) {
                deselect($(this));
            } else {
                $(this).addClass('selected');
                $('.pop').slideFadeToggle();
            }
            return false;
        });

        $('.close').on('click', function() {
            deselect($('.easytheme-show-statement'));
            return false;
        });
        $(this).easytheme(jQuery.parseJSON(response.data));
    });
});